Module event

Module event 

Enums

EditCommand
Editing actions which can be mapped to key bindings.
LineEditorEvent
LineEditor supported actions.
MovementCommand
Movements actions which can be mapped to key bindings.